@@ -10,7 +10,7 @@ import platform
 import dask.array as da
 import dask
 import warnings
-from pycromanager.core import Bridge
+from pycromanager.zmq import Bridge
 import struct
 from pycromanager.legacy_data import Legacy_NDTiff_Dataset
 import threading
@@ -298,7 +298,7 @@ def _storage_monitor_fn(
             axes = dataset._add_index_entry(index_entry)
 
             if callback_fn is not None:
-                callback_fn(axes)
+                callback_fn(axes, dataset)
 
 
 class Dataset:
